PairRE
======

.. currentmodule:: pykeen.models

.. autoclass:: PairRE
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PairRE.default_entity_normalizer_kwargs
      ~PairRE.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: default_entity_normalizer_kwargs
   .. autoattribute:: hpo_default
